@@ -825,8 +825,9 @@ class CameraDevice(Protocol):
     async def disconnect(self) -> None: ...
     async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
-    async def get_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
+    async def get_frames(self, options: ImageOptions = {}) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
+    async def get_prebuffered_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
 
